@@ -27,8 +27,8 @@ XAS::Class - A Perl extension for the XAS environment
 
 This module ties the XAS environment to the base Badger object framework. It
 exposes the defined constants and utilities that reside in L<XAS::Constants|XAS::Constants> and
-L<XAS::Utils|XAS::Utils>. Which inherits from L<Badger::Constants|http://badgerpower.com/docs/Badger/Class.html> and 
-L<Badger::Utils|http://badgerpower.com/docs/Badger/Utils.html>.
+L<XAS::Utils|XAS::Utils>. Which inherits from L<Badger::Constants|https://metacpan.org/pod/Badger::Constants> and 
+L<Badger::Utils|http://metacpan.org/pod/Badger::Utils>.
 
 =head1 SEE ALSO
 
@@ -46,10 +46,8 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 Copyright (C) 2014 Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-See L<http://dev.perl.org/licenses/> for more information.
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
