@@ -36,14 +36,14 @@ XAS::Exception - The base exception class for the XAS environment
 =head1 DESCRIPTION
 
 This module defines a base exception class for the XAS Environment and 
-inherits from L<Badger::Exception|http://badgerpower.com/docs/Badger/Exception.html>. 
+inherits from L<Badger::Exception|https://metacpan.org/Badger::Exception>. 
 The only differences is that it turns stack tracing on by default.
 
 =head1 METHODS
 
 =head2 stack_trace
 
-Removes any reference to Try::Tiny in the stack trace.
+Removes any reference to L<Try::Tiny|https://metacpan.org/pod/Try::Tiny> in the stack trace.
 
 =head1 SEE ALSO
 
@@ -61,10 +61,8 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 Copyright (C) 2014 Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-See L<http://dev.perl.org/licenses/> for more information.
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
