@@ -8,12 +8,13 @@ use Hash::Merge;
 use Getopt::Long;
 
 use XAS::Class
-  debug   => 0,
-  version => $VERSION,
-  base    => 'XAS::Base',
-  mixin   => 'XAS::Lib::Mixins::Handlers',
-  import  => 'CLASS',
-  utils   => 'dotid',
+  debug      => 0,
+  version    => $VERSION,
+  base       => 'XAS::Base',
+  mixin      => 'XAS::Lib::Mixins::Handlers',
+  import     => 'CLASS',
+  utils      => 'dotid',
+  filesystem => 'File',
   vars => {
     PARAMS => {
       -throws   => { optional => 1, default => 'changeme' },
@@ -122,18 +123,22 @@ sub _default_options {
     my $self = shift;
 
     my $version = $self->CLASS->VERSION;
-    my $script  = $self->class->any_var('SCRIPT');
+    my $script  = $self->env->script;
 
     return {
-        'logtype=s' => sub { $self->env->logtype($_[1]) },
-        'alerts!'   => sub { $self->alerts->on($_[1]); },
-        'debug'     => sub { $self->debugging(1); },
-        'help|h|?'  => sub { pod2usage(-verbose => 0, -exitstatus => 0); },
-        'manual'    => sub { pod2usage(-verbose => 2, -exitstatus => 0); },
-        'version'   => sub { printf("%s - v%s\n", $script, $version); exit 0; },
+        'log-type=s'     => sub { $self->env->log_type($_[1]); },
+        'log-facility=s' => sub { $self->env->log_facility($_[1]); },
+        'alerts!'        => sub { $self->env->alerts($_[1]); },
+        'help|h|?'       => sub { pod2usage(-verbose => 0, -exitstatus => 0); },
+        'manual'         => sub { pod2usage(-verbose => 2, -exitstatus => 0); },
+        'version'        => sub { printf("%s - v%s\n", $script, $version); exit 0; },
+        'debug'          => sub { 
+            $self->env->xdebug(1); 
+            $self->log->level('debug', 1);
+        },
         'logfile=s' => sub {
             my $logfile = File($_[1]);
-            $self->env->logtype('file');
+            $self->env->log_type('file');
             $self->env->logfile($logfile);
         }
     };
@@ -215,7 +220,7 @@ Example
 If an exception is caught, the global exception handler will send an alert, 
 write the exception to the log and returns an exit code of 1. 
 
-=item Normal Completiion
+=item Normal Completion
 
 When the procedure completes successfully, it will return an exit code of 0. 
 
@@ -230,8 +235,8 @@ This is where your main line logic starts.
 =head2 options
 
 This method sets up additional cli options. Option handling is provided
-by Getopt::Long. To access these options you need to define accessors for
-them.
+by L<Getopt::Long|https://metacpan.org/pod/Getopt::Long>. To access these 
+options you need to define accessors for them.
 
   Example
 
@@ -321,10 +326,15 @@ This displaces the procedures manual in the defined pager.
 
 This prints out the version of the module.
 
-=head2 --logtype
+=head2 --log-type
 
 What type of log to use. By default the log is displayed on the console. Log
-types can be one of the following "console", "file", "logstash" or "syslog".
+types can be one of the following "console", "file", "json" or "syslog".
+
+=head2 --log-facility
+
+What log facility class to use. This follows syslog convention. By default 
+the facility is "local6".
 
 =head2 --logfile
 
@@ -345,12 +355,10 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 Kevin L. Esteb
+Copyright (c) 2014 Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-See L<http://dev.perl.org/licenses/> for more information.
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
