@@ -1,8 +1,9 @@
 package XAS::Lib::Net::Server;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use POE;
+use Try::Tiny;
 use Socket ':all';
 use POE::Filter::Line;
 use POE::Wheel::ReadWrite;
@@ -11,8 +12,8 @@ use POE::Wheel::SocketFactory;
 use XAS::Class
   debug     => 0,
   version   => $VERSION,
-  base      => 'XAS::Lib::Service',
-  mixin     => 'XAS::Lib::Mixins::Keepalive',
+  base      => 'XAS::Lib::POE::Service',
+  mixin     => 'XAS::Lib::Mixins::Handlers',
   utils     => 'weaken params',
   accessors => 'session',
   constants => 'ARRAY',
@@ -23,7 +24,7 @@ use XAS::Class
       -inactivity_timer => { optional => 1, default => 600 },
       -filter           => { optional => 1, default => undef },
       -address          => { optional => 1, default => 'localhost' },
-      -eol              => { optional => 1, default => "\012\015" },
+      -eol              => { optional => 1, default => "\015\012" },
     }
   }
 ;
@@ -41,10 +42,6 @@ sub session_initialize {
 
     $self->log->debug("$alias: entering session_intialize()");
 
-    $poe_kernel->state('process_errors',   $self);
-    $poe_kernel->state('process_request',  $self);
-    $poe_kernel->state('process_response', $self);
-
     # private events
 
     $poe_kernel->state('client_error',             $self, '_client_error');
@@ -55,6 +52,11 @@ sub session_initialize {
     $poe_kernel->state('client_connection',        $self, '_client_connection');
     $poe_kernel->state('client_connection_failed', $self, '_client_connection_failed');
 
+    $poe_kernel->state('process_errors',    $self, '_process_errors');
+    $poe_kernel->state('process_request',   $self, '_process_request');
+    $poe_kernel->state('process_response',  $self, '_process_response');
+    $poe_kernel->state('handle_connection', $self, '_handle_connection');
+
     # walk the chain
 
     $self->SUPER::session_initialize();
@@ -124,7 +126,7 @@ sub session_pause {
 
     $self->SUPER::session_pause();
 
-    $self->log->debug("$alias: entering session_pause()");
+    $self->log->debug("$alias: leaving session_pause()");
 
 }
 
@@ -153,34 +155,68 @@ sub session_resume {
 }
 
 sub reaper {
-    my ($self, $wheel) = @_;
+    my $self = shift;
+    my ($wheel) = $self->validate_params(\@_, [1]);
 
     my $alias = $self->alias;
 
-    $self->log->debug_msg('reaper', $alias, $self->host($wheel), $self->peerport($wheel));
+    $self->log->debug_msg('net_client_reaper', $alias, $self->host($wheel), $self->peerport($wheel));
 
 }
 
+sub process_request {
+    my $self = shift;
+    my ($input, $ctx) = $self->validate_params(\@_, [1,1]);
+
+    return $input;
+
+}
+
+sub process_response {
+    my $self = shift;
+    my ($output, $ctx) = $self->validate_params(\@_, [1,1]);
+
+    return $output;
+
+}
+
+sub process_errors {
+    my $self = shift;
+    my ($output, $ctx) = $self->validate_params(\@_, [1,1]);
+
+    return $output;
+
+}
+
+sub handle_connection {
+    my $self = shift;
+    my ($wheel) = $self->validate_params(\@_, [1]);
+    
+}
+
 # ----------------------------------------------------------------------
 # Public Accessors
 # ----------------------------------------------------------------------
 
 sub peerport {
-    my ($self, $wheel) = @_;
+    my $self = shift;
+    my ($wheel) = $self->validate_params(\@_, [1]);
 
     return $self->{clients}->{$wheel}->{port};
 
 }
 
 sub peerhost {
-    my ($self, $wheel) = @_;
+    my $self = shift;
+    my ($wheel) = $self->validate_params(\@_, [1]);
 
     return $self->{clients}->{$wheel}->{host};
 
 }
 
 sub client {
-    my ($self, $wheel) = @_;
+    my $self = shift;
+    my ($wheel) = $self->validate_params(\@_, [1]);
 
     return $self->{clients}->{$wheel}->{client};
 
@@ -190,40 +226,55 @@ sub client {
 # Public Events
 # ----------------------------------------------------------------------
 
-sub process_request {
-    my ($self, $input, $ctx) = @_[OBJECT,ARG0,ARG1];
-
-    my $output = $input;
-    my $alias = $self->alias;
-
-    $poe_kernel->post($alias, 'process_response', $output, $ctx);
-
-}
-
-sub process_response {
-    my ($self, $output, $ctx) = @_[OBJECT,ARG0,ARG1];
-
-    my $alias = $self->alias;
-
-    $poe_kernel->post($alias, 'client_output', $output, $ctx);
-
-}
-
-sub process_errors {
-    my ($self, $output, $ctx) = @_[OBJECT,ARG0,ARG1];
-
-    my $alias = $self->alias;
-
-    $poe_kernel->post($alias, 'client_output', $output, $ctx);
-
-}
-
 # ----------------------------------------------------------------------
 # Private Events
 # ----------------------------------------------------------------------
 
+sub _process_request {
+    my ($self, $input, $ctx) = @_[OBJECT,ARG0,ARG1];
+
+    my $alias = $self->alias;
+    my $data  = $self->process_request($input, $ctx);
+
+    $self->log->debug("$alias: _process_request()");
+    $poe_kernel->post($alias, 'process_response', $data, $ctx);
+
+}
+
+sub _process_response {
+    my ($self, $output, $ctx) = @_[OBJECT,ARG0,ARG1];
+
+    my $alias = $self->alias;
+    my $data  = $self->process_response($output, $ctx);
+
+    $self->log->debug("$alias: _process_response()");
+    $poe_kernel->post($alias, 'client_output', $data, $ctx);
+
+}
+
+sub _process_errors {
+    my ($self, $output, $ctx) = @_[OBJECT,ARG0,ARG1];
+
+    my $alias = $self->alias;
+    my $data  = $self->process_errors($output, $ctx);
+
+    $self->log->debug("$alias: _process_errors()");
+    $poe_kernel->post($alias, 'client_output', $data, $ctx);
+
+}
+
+sub _handle_connection {
+    my ($self, $wheel) = @_[OBJECT, ARG0];
+
+    my $alias = $self->alias;
+
+    $self->log->debug("$alias: _handle_connection()");
+    $self->handle_connection($wheel);
+
+}
+
 sub _client_connection {
-    my ($self) = @_[OBJECT];
+    my ($self) = $_[OBJECT];
 
     my $alias = $self->alias;
 
@@ -252,14 +303,6 @@ sub _client_connected {
 
     $self->log->debug("$alias: _client_connected()");
 
-    if ($self->tcp_keepalive) {
-
-        $self->log->debug("$alias: keepalive activated");
-
-        $self->enable_keepalive($socket);
-
-    }
-
     my $client = POE::Wheel::ReadWrite->new(
         Handle     => $socket,
         Filter     => $self->filter,
@@ -274,10 +317,13 @@ sub _client_connected {
     $self->{clients}->{$wheel}->{port}   = $peerport;
     $self->{clients}->{$wheel}->{client} = $client;
     $self->{clients}->{$wheel}->{active} = time();
+    $self->{clients}->{$wheel}->{socket} = $socket;
     $self->{clients}->{$wheel}->{watchdog} = $poe_kernel->alarm_set('client_reaper', $inactivity, $wheel);
 
-    $self->log->info_msg('client_connect', $alias, $host, $peerport);
+    $self->log->info_msg('net_client_connect', $alias, $host, $peerport);
 
+    $poe_kernel->post($alias, 'handle_connection', $wheel);
+    
 }
 
 sub _client_connection_failed {
@@ -285,7 +331,7 @@ sub _client_connection_failed {
 
     my $alias = $self->alias;
 
-    $self->log->error_msg('connection_failed', $alias, $errnum, $errstr);
+    $self->log->error_msg('net_client_connection_failed', $alias, $errnum, $errstr);
 
     delete $self->{listener};
 
@@ -310,22 +356,52 @@ sub _client_input {
 sub _client_output {
     my ($self, $data, $ctx) = @_[OBJECT,ARG0,ARG1];
 
-    my @packet;
     my $alias = $self->alias;
-
-    push(@packet, $data);
+    my $wheel = $ctx->{wheel};
+    my @buffer;
 
     $self->log->debug("$alias: _client_output()");
 
-    if (my $wheel = $ctx->{wheel})) {
+    try {
 
-        $self->{clients}->{$wheel}->{client}->put(@packet);
+        if (defined($wheel)) {
 
-    } else {
+            # emulate IO::Socket connected() method. this method
+            # calls getpeername(). getpeername() returns undef when
+            # the network stack can't validate the socket. 
 
-        $self->log->error_msg('nowheel', $alias);
+            if (getpeername($self->{clients}->{$wheel}->{socket})) {
 
-    }
+                push(@buffer, $data);
+                $self->{clients}->{$wheel}->{client}->put(@buffer);
+
+            } else {
+
+                $self->log->error_msg(
+                    'net_client_nosocket', 
+                    $alias, 
+                    $self->peerhist($wheel), 
+                    $self->peerport($wheel)
+                );
+                delete $self->{clients}->{$wheel};
+
+            }
+
+        } else {
+
+            $self->log->error_msg('net_client_nowheel', $alias);
+
+        }
+
+    } catch {
+
+        my $ex = $_;
+
+        $self->exception_handler($ex);
+
+        delete $self->{clients}->{$wheel};
+
+    };
 
 }
 
@@ -338,11 +414,11 @@ sub _client_error {
 
     if ($errnum == 0) {
 
-        $self->log->info_msg('client_disconnect', $alias, $self->peerhost($wheel), $self->peerport($wheel));
+        $self->log->info_msg('net_client_disconnect', $alias, $self->peerhost($wheel), $self->peerport($wheel));
 
     } else {
 
-        $self->log->error_msg('client_error', $alias, $errnum, $errstr);
+        $self->log->error_msg('net_client_error', $alias, $errnum, $errstr);
 
     }
 
@@ -372,8 +448,6 @@ sub init {
 
     my $self = $class->SUPER::init(@_);
 
-    $self->init_keepalive();     # init tcp keepalive definations
-
     unless (defined($self->filter)) {
 
         $self->{filter} = POE::Filter::Line->new(
@@ -399,19 +473,19 @@ XAS::Lib::Net::Server - A basic network server for the XAS Environment
 
  my $server = XAS::Lib::Net::Server->new(
      -port             => 9505,
-     -address          => 'localhost',
+     -host             => 'localhost',
      -filter           => POE::Filter::Line->new(),
      -alias            => 'server',
      -inactivity_timer => 600,
-     -eol              => "\012\015"
+     -eol              => "\015\012"
  }
 
 =head1 DESCRIPTION
 
 This module implements a simple text orientated network protocol. Data is
-sent out as "packets". Which means everything is delimited with a consistent
-EOL. These packets may be formatted strings, such as JSON. This module inherits
-from L<XAS::Lib::Session>.
+sent out as delimited strings. Which means every string has a consistent EOL. 
+These strings may be formatted, such as JSON. This module inherits from 
+L<XAS::Lib::POE::Session|XAS::Lib::POE::Session>.
 
 =head1 METHODS
 
@@ -446,7 +520,7 @@ An optional filter to use, defaults to POE::Filter::Line
 
 =item B<-eol>
 
-An optional EOL, defaults to "\012\015";
+An optional EOL, defaults to "\015\012";
 
 =back
 
@@ -462,6 +536,73 @@ The POE wheel that triggered the timer.
 
 =back
 
+=head2 process_request($input, $ctx)
+
+This method will process the input from the client. It takes the
+following parameters:
+
+=over 4
+
+=item B<$input>
+
+The input received from the socket.
+
+=item B<$ctx>
+
+A hash variable to maintain context. This will be initialized with a "wheel"
+field. Others fields may be added as needed.
+
+=back
+
+=head2 process_response($output, $ctx)
+
+This method will process the output from the client. It takes the
+following parameters:
+
+=over 4
+
+=item B<$output>
+
+The output to be sent to the socket.
+
+=item B<$ctx>
+
+A hash variable to maintain context. This uses the "wheel" field to direct 
+output to the correct socket. Others fields may have been added as needed.
+
+=back
+
+=head2 process_errors($output, $ctx)
+
+This method will process the error output from the client. It takes the
+following parameters:
+
+=over 4
+
+=item B<$output>
+
+The output to be sent to the socket.
+
+=item B<$ctx>
+
+A hash variable to maintain context. This uses the "wheel" field to direct 
+output to the correct socket. Others fields may have been added as needed.
+
+=back
+
+=head2 handle_connection($wheel)
+
+This method is called after the client connects. This is for additional
+post connection processing as needed. It takes the following parameters:
+
+=over 4
+
+=item B<$wheel>
+
+The id of the clients wheel.
+
+=back
+
 =head1 ACCESSORS
 
 =head2 peerport($wheel)
@@ -500,79 +641,11 @@ The POE wheel to use.
 
 =back
 
-=head1 PUBLIC EVENTS
-
-=head2 process_request(OBJECT, ARG0, ARG1)
-
-This event will process the input from the client. It takes the
-following parameters:
-
-=over 4
-
-=item B<OBJECT>
-
-A handle to the current object.
-
-=item B<ARG0>
-
-The input received from the socket.
-
-=item B<ARG1>
-
-A hash variable to maintain context. This will be initialized with a "wheel"
-field. Others fields may be added as needed.
-
-=back
-
-=head2 process_response(OBJECT, ARG0, ARG1)
-
-This event will process the output from the client. It takes the
-following parameters:
-
-=over 4
-
-=item B<OBJECT>
-
-A handle to the current object.
-
-=item B<ARG0>
-
-The output to be sent to the socket.
-
-=item B<ARG1>
-
-A hash variable to maintain context. This uses the "wheel" field to direct output
-to the correct socket. Others fields may have been added as needed.
-
-=back
-
-=head2 process_errors(OBJECT, ARG0, ARG1)
-
-This event will process the error output from the client. It takes the
-following parameters:
-
-=over 4
-
-=item B<OBJECT>
-
-A handle to the current object.
-
-=item B<ARG0>
-
-The output to be sent to the socket.
-
-=item B<ARG1>
-
-A hash variable to maintain context. This uses the "wheel" field to direct output
-to the correct socket. Others fields may have been added as needed.
-
-=back
-
 =head1 SEE ALSO
 
 =over 4
 
-=item POE::Filter::Line
+=item L<POE::Filter::Line|https://metacpan.org/pod/POE::Filter::Line>
 
 =item L<XAS|XAS>
 
@@ -584,12 +657,10 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 Kevin L. Esteb
+Copyright (c) 2014 Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-See L<http://dev.perl.org/licenses/> for more information.
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
