@@ -5,16 +5,11 @@ our $VERSION = '0.01';
 use XAS::Lib::Stomp::Frame;
 
 use XAS::Class
-  debug     => 0,
-  version   => $VERSION,
-  base      => 'XAS::Base',
-  utils     => 'trim',
-  accessors => 'target',
-  vars => {
-    PARAMS => {
-      -target  => { optional => 1, default => '1.0', regex => qr/(1\.0|1\.1|1\.2)/ },
-    }
-  }
+  debug   => 0,
+  version => $VERSION,
+  base    => 'XAS::Base',
+  mixin   => 'XAS::Lib::Mixins::Bufops',
+  utils   => 'trim',
 ;
 
 our $EOF    = "\000";
@@ -43,7 +38,7 @@ sub parse {
 
     $self->{buffer} .= $buffer;
 
-    $self->log->debug('buffer');
+    $self->log->debug('stomp parse');
 #    $self->log->debug(hexdump($self->{buffer}));
 
     # A valid frame is usually this:
@@ -79,7 +74,7 @@ sub parse {
             # start of the frame 
             # check for a valid buffer, must have a EOL someplace.
 
-            if ($line = $self->_read_line($EOL)) {
+            if ($line = $self->buf_get_line(\$self->{buffer}, $EOL)) {
 
                 $self->log->debug('command');
 #                $self->log->debug(hexdump($line));
@@ -117,7 +112,7 @@ sub parse {
 
             if (($clength != -1) && ($clength <= $length)) {
 
-                $line = $self->_slurp($clength);
+                $line = $self->buf_slurp(\$self->{buffer}, $clength);
 #                $self->log->debug(hexdump($line));
 
                 while ($line =~ s/^$HEADER//) {
@@ -132,7 +127,7 @@ sub parse {
                     # the last defined header is honored. The duplictes
                     # are discarded.
 
-                    if ($self->target < 1.2) {
+                    if ($self->env->mqlevel < 1.2) {
 
                         $self->{headers}->{$key} = $value;
 
@@ -169,7 +164,7 @@ sub parse {
 
                 if ($clength <= $length) {
 
-                    $self->{body} = $self->_slurp($clength);
+                    $self->{body} = $self->buf_slurp(\$self->{buffer}, $clength);
                     $self->{state} = 'frame';
 
                 } else { last; }
@@ -182,7 +177,7 @@ sub parse {
 
                 if (($clength != -1) && ($clength <= $length)) {
 
-                    $self->{body} = $self->_read_line($EOF);
+                    $self->{body} = $self->buf_get_line(\$self->{buffer}, $EOF);
                     chop $self->{body};
                     $self->{state} = 'frame';
 
@@ -199,7 +194,6 @@ sub parse {
             $self->{buffer} =~ s/^$CNTRL//;
 
             $frame = XAS::Lib::Stomp::Frame->new(
-                -target  => $self->target,
                 -command => $self->{command},
                 -headers => $self->{headers},
                 -body    => $self->{body}
@@ -245,40 +239,6 @@ sub init {
 
 }
 
-sub _read_line {
-    my $self = shift;
-    my $eol  = shift;
-
-    my $pos;
-    my $buffer;
-
-    if ($self->{buffer} =~ m/$eol/g) {
-
-        $pos = pos($self->{buffer});
-        $buffer = $self->_slurp($pos);
-
-    }
-
-    return $buffer;
-
-}
-
-sub _slurp {
-    my $self = shift;
-    my $pos  = shift;
-
-    my $buffer;
-
-    if ($buffer = substr($self->{buffer}, 0, $pos)) {
-
-        substr($self->{buffer}, 0, $pos) = "";
-
-    }
-
-    return $buffer;
-
-}
-
 1;
 
 __END__
@@ -291,9 +251,7 @@ XAS::Lib::Stomp::Parse - Create a STOMP Frame From a Buffer
 
   use XAS::Lib::Stomp::Parser;
 
-  my $parser = XAS::Lib::Stomp::Parser->new(
-    -target  => '1.0',
-  );
+  my $parser = XAS::Lib::Stomp::Parser->new();
 
   while (my $buffer = read()) {
 
@@ -320,16 +278,7 @@ A STOMP frame consists of a command, a series of headers and a body.
 
 =head2 new
 
-Creates a new parser. It can take the following parameters:
-
-=over 4
-
-=item B<-target>
-
-Specify a STOMP protocol version number. It currently supports 1.0,
-1.1 and 1.2, defaulting to 1.0.
-
-=back
+Creates a new parser.
 
 =head2 get_pending
 
@@ -339,7 +288,7 @@ Returns the contents of the internal buffer.
 
 =over 4
 
-=item L< XAS|XAS>
+=item L<XAS|XAS>
 
 =back
 
@@ -353,10 +302,8 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 Copyright (C) 2014 Kevin L. Esteb
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
-
-See L<http://dev.perl.org/licenses/> for more information.
+This is free software; you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0. For details, see the full text
+of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
